public

# Builds the enumeration snd_pcm_format_t according to the endianness.
#
# * *Returns* :
#   - the enumeration snd_pcm_format_t.
# * *Raises* :
#   - +StandardError+ -> if the endianness is neither little nor big.
def get_format
  num       = 0x12345678
  little    = '78563412'
  big       = '12345678'
  native    = [num].pack('l')
  netunpack = native.unpack('N')[0]
  str       = '%8x' % netunpack
  case str
  when little
    PCM_FORMAT_COMMON + PCM_FORMAT_LE
  when big
    PCM_FORMAT_COMMON + PCM_FORMAT_BE
  else
    fail StandardError.new('Your endianness is not handled')
  end
end

private

PCM_FORMAT_COMMON = [:SND_PCM_FORMAT_UNKNOWN            , -1 ,
                     :SND_PCM_FORMAT_S8                 ,  0 ,
                     :SND_PCM_FORMAT_U8                 ,
                     :SND_PCM_FORMAT_S16_LE             ,
                     :SND_PCM_FORMAT_S16_BE             ,
                     :SND_PCM_FORMAT_U16_LE             ,
                     :SND_PCM_FORMAT_U16_BE             ,
                     :SND_PCM_FORMAT_S24_LE             ,
                     :SND_PCM_FORMAT_S24_BE             ,
                     :SND_PCM_FORMAT_U24_LE             ,
                     :SND_PCM_FORMAT_U24_BE             ,
                     :SND_PCM_FORMAT_S32_LE             ,
                     :SND_PCM_FORMAT_S32_BE             ,
                     :SND_PCM_FORMAT_U32_LE             ,
                     :SND_PCM_FORMAT_U32_BE             ,
                     :SND_PCM_FORMAT_FLOAT_LE           ,
                     :SND_PCM_FORMAT_FLOAT_BE           ,
                     :SND_PCM_FORMAT_FLOAT64_LE         ,
                     :SND_PCM_FORMAT_FLOAT64_BE         ,
                     :SND_PCM_FORMAT_IEC958_SUBFRAME_LE ,
                     :SND_PCM_FORMAT_IEC958_SUBFRAME_BE ,
                     :SND_PCM_FORMAT_MU_LAW             ,
                     :SND_PCM_FORMAT_A_LAW              ,
                     :SND_PCM_FORMAT_IMA_ADPCM          ,
                     :SND_PCM_FORMAT_MPEG               ,
                     :SND_PCM_FORMAT_GSM                ,
                     :SND_PCM_FORMAT_SPECIAL            ,  31 ,
                     :SND_PCM_FORMAT_S24_3LE            ,  32 ,
                     :SND_PCM_FORMAT_S24_3BE            ,
                     :SND_PCM_FORMAT_U24_3LE            ,
                     :SND_PCM_FORMAT_U24_3BE            ,
                     :SND_PCM_FORMAT_S20_3LE            ,
                     :SND_PCM_FORMAT_S20_3BE            ,
                     :SND_PCM_FORMAT_U20_3LE            ,
                     :SND_PCM_FORMAT_U20_3BE            ,
                     :SND_PCM_FORMAT_S18_3LE            ,
                     :SND_PCM_FORMAT_S18_3BE            ,
                     :SND_PCM_FORMAT_U18_3LE            ,
                     :SND_PCM_FORMAT_U18_3BE            ,
                     :SND_PCM_FORMAT_LAST               , 44]

PCM_FORMAT_LE = [:SND_PCM_FORMAT_S16            , 2 ,
                 :SND_PCM_FORMAT_U16            , 4 ,
                 :SND_PCM_FORMAT_S24            , 6 ,
                 :SND_PCM_FORMAT_U24            , 8 ,
                 :SND_PCM_FORMAT_S32            , 10,
                 :SND_PCM_FORMAT_U32            , 12,
                 :SND_PCM_FORMAT_FLOAT          , 14,
                 :SND_PCM_FORMAT_FLOAT64        , 16,
                 :SND_PCM_FORMAT_IEC958_SUBFRAME, 18]

PCM_FORMAT_BE = [:SND_PCM_FORMAT_S16            , 3 ,
                 :SND_PCM_FORMAT_U16            , 5 ,
                 :SND_PCM_FORMAT_S23            , 7 ,
                 :SND_PCM_FORMAT_U24            , 9 ,
                 :SND_PCM_FORMAT_S32            , 11,
                 :SND_PCM_FORMAT_U32            , 13,
                 :SND_PCM_FORMAT_FLOAT          , 15,
                 :SND_PCM_FORMAT_FLOAT64        , 17,
                 :SND_PCM_FORMAT_IEC958_SUBFRAME, 19]

