require 'rb-alsacap/libasound'
require 'rb-alsacap/alsa_error'

module AlsaCap
  # A class that represents an audio subdevice.
  class SubDevice
    attr_reader :number
    attr_reader :name

    # Returns a new subdevice.
    #
    # * *Args*    :
    #   - +card_n+ -> card number.
    #   - +dev_n+ -> device number.
    #   - +subdev_n+ -> subdevice number.
    #   - +pcm_info+ -> a PCM generic info structure.
    #   - +ctl_handle+ -> a CTL handle.
    def initialize(card_n, dev_n, subdev_n, pcm_info, ctl_handle)
      @number = subdev_n
      @name   = nil
      LibAsound.snd_pcm_info_set_subdevice(pcm_info, @number)
      if LibAsound.snd_ctl_pcm_info(ctl_handle, pcm_info) >= 0
        @name = LibAsound.snd_pcm_info_get_subdevice_name(pcm_info)
      else
        AlsaCap.throw_AlsaError(err, 'obtaining subdevice info', card_n, dev_n)
      end
    end

    # Returns a string representing the subdevice.
    #
    # * *Returns* :
    #   - a string representing the subdevice.
    def to_s
      "Subdevice #{@number}, name '#{@name}'"
    end
  end
end
